@@ -1,4 +1,13 @@
-model.covariance <- function(type, cov, param)
+model.mean <- function(type, center, param)
+{
+    if (length(which(is.na(center))) > 0)
+        matrix(NA, 1, ncol(center))
+    else if (type == resolve.type("mean"))
+        param$mean
+    else center
+}
+
+model.covariance <- function(type, cov, mean, param)
 {
     if (length(which(is.na(cov))) > 0)
         matrix(NA, nrow(cov), ncol(cov))
@@ -16,6 +25,12 @@ model.covariance <- function(type, cov, param)
         D <- diag(sort(param$eigenvalues, decreasing=T))
         V %*% D %*% t(V)
     }
+    else if (type == resolve.type("mean"))
+    {    
+        m = param$mean
+        mean_diff = m - mean
+        cov + (mean_diff %*% t(mean_diff))
+    }
     else if (type == resolve.type("all"))
         cov
 }
\ No newline at end of file
